package com.ynet.life.file;

import com.lowagie.text.Document;
import com.lowagie.text.ExceptionConverter;
import com.lowagie.text.Font;
import com.lowagie.text.Image;
import com.lowagie.text.Phrase;
import com.lowagie.text.Rectangle;
import com.lowagie.text.pdf.BaseFont;
import com.lowagie.text.pdf.PdfContentByte;
import com.lowagie.text.pdf.PdfPCell;
import com.lowagie.text.pdf.PdfPTable;
import com.lowagie.text.pdf.PdfPageEventHelper;
import com.lowagie.text.pdf.PdfTemplate;
import com.lowagie.text.pdf.PdfWriter;
import com.ynet.life.base.LifeStandard;
import java.text.SimpleDateFormat;
import java.util.Date;

/* loaded from: com_ynet_life_file.jar:com/ynet/life/file/CommonPDFPageEventHelper.class */
public class CommonPDFPageEventHelper extends PdfPageEventHelper {
    public static final String logoImg = "/images/pdf-logo.JPG";
    private PdfTemplate tpl;
    private BaseFont bf;
    private String title;
    private String creator;

    public CommonPDFPageEventHelper(String title, String creator) {
        this.title = title;
        this.creator = creator;
    }

    public void onOpenDocument(PdfWriter writer, Document document) {
        try {
            this.tpl = writer.getDirectContent().createTemplate(100.0f, 100.0f);
            this.bf = BaseFont.createFont("STSong-Light", "UniGB-UCS2-H", false);
        } catch (Exception e) {
            throw new ExceptionConverter(e);
        }
    }

    /* JADX WARN: Type inference failed for: r0v19, types: [float, java.lang.Exception] */
    public void onStartPage(PdfWriter writer, Document document) {
        ?? writeSelectedRows;
        try {
            Rectangle page = document.getPageSize();
            PdfPTable headTable = new PdfPTable(2);
            headTable.setWidths(new int[]{10, 50});
            PdfPCell cell1 = new PdfPCell();
            cell1.setHorizontalAlignment(0);
            cell1.setVerticalAlignment(5);
            cell1.setBorder(0);
            Image img = Image.getInstance(String.valueOf(LifeStandard.getRootPath()) + logoImg);
            cell1.addElement(img);
            headTable.addCell(cell1);
            PdfPCell cell2 = new PdfPCell(new Phrase(this.title));
            cell2.setHorizontalAlignment(1);
            cell2.setVerticalAlignment(5);
            cell2.setBorder(0);
            headTable.addCell(cell2);
            headTable.setTotalWidth((page.getWidth() - document.leftMargin()) - document.rightMargin());
            writeSelectedRows = headTable.writeSelectedRows(0, -1, document.leftMargin(), 822.0f, writer.getDirectContent());
        } catch (Exception e) {
            writeSelectedRows.printStackTrace();
        }
    }

    public void onEndPage(PdfWriter writer, Document document) {
        PdfContentByte cb;
        try {
            Rectangle page = document.getPageSize();
            Font ft = new Font(this.bf, 7.0f, 2);
            PdfPTable footTable = new PdfPTable(3);
            footTable.setWidths(new int[]{10, 40, 50});
            PdfPCell cell11 = new PdfPCell();
            PdfPCell cell12 = new PdfPCell();
            PdfPCell cell13 = new PdfPCell();
            PdfPCell cell21 = new PdfPCell();
            PdfPCell cell22 = new PdfPCell();
            PdfPCell cell23 = new PdfPCell();
            cell11.addElement(new Phrase("Printed By", ft));
            cell11.setBorderWidthLeft(1.0f);
            cell11.setBorderWidthTop(1.0f);
            cell11.setBorderWidthRight(0.0f);
            cell11.setBorderWidthBottom(0.0f);
            cell11.setPaddingLeft(4.0f);
            footTable.addCell(cell11);
            cell12.addElement(new Phrase(this.creator, ft));
            cell12.setBorderWidthTop(1.0f);
            cell12.setBorderWidthLeft(0.0f);
            cell12.setBorderWidthRight(0.0f);
            cell12.setBorderWidthBottom(0.0f);
            cell12.setPaddingLeft(4.0f);
            footTable.addCell(cell12);
            cell13.addElement(new Phrase("", ft));
            cell13.setBorderWidthRight(1.0f);
            cell13.setBorderWidthTop(1.0f);
            cell13.setBorderWidthLeft(0.0f);
            cell13.setBorderWidthBottom(0.0f);
            cell13.setPaddingLeft(4.0f);
            footTable.addCell(cell13);
            cell21.addElement(new Phrase("Printed On", ft));
            cell21.setBorderWidthLeft(1.0f);
            cell21.setBorderWidthBottom(1.0f);
            cell21.setBorderWidthTop(0.0f);
            cell21.setBorderWidthRight(0.0f);
            cell21.setPadding(4.0f);
            footTable.addCell(cell21);
            SimpleDateFormat df = new SimpleDateFormat("dd-MM-yyyy HH:mm:ss");
            cell22.addElement(new Phrase(df.format(new Date()), ft));
            cell22.setBorderWidthBottom(1.0f);
            cell22.setBorderWidthTop(0.0f);
            cell22.setBorderWidthLeft(0.0f);
            cell22.setBorderWidthRight(0.0f);
            cell22.setPadding(4.0f);
            footTable.addCell(cell22);
            cell23.addElement(new Phrase("", ft));
            cell23.setBorderWidthRight(1.0f);
            cell23.setBorderWidthBottom(1.0f);
            cell23.setBorderWidthLeft(0.0f);
            cell23.setBorderWidthTop(0.0f);
            cell23.setPadding(4.0f);
            footTable.addCell(cell23);
            footTable.setTotalWidth((page.getWidth() - document.leftMargin()) - document.rightMargin());
            footTable.writeSelectedRows(0, -1, document.leftMargin(), document.bottomMargin() + 20.0f, writer.getDirectContent());
            cb = writer.getDirectContent();
            String text = "page  " + writer.getPageNumber() + "  of   ";
            cb.beginText();
            cb.setFontAndSize(this.bf, 7.0f);
            cb.setTextMatrix(510.0f, 44.0f);
            cb.showText(text);
            cb.endText();
            cb.addTemplate(this.tpl, 548.0f, 44.0f);
            cb.saveState();
            cb.stroke();
            cb.restoreState();
            cb.closePath();
        } catch (Exception e) {
            cb.printStackTrace();
        }
    }

    public void onCloseDocument(PdfWriter writer, Document document) {
        this.tpl.beginText();
        this.tpl.setFontAndSize(this.bf, 7.0f);
        this.tpl.showText(Integer.toString(writer.getPageNumber() - 1));
        this.tpl.endText();
        this.tpl.closePath();
    }
}
